//
//  The MIT License (MIT)
//  Copyright (c) 2019 Oleg Geier
//
//  Permission is hereby granted, free of charge, to any person obtaining a copy of
//  this software and associated documentation files (the "Software"), to deal in
//  the Software without restriction, including without limitation the rights to
//  use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
//  of the Software, and to permit persons to whom the Software is furnished to do
//  so, subject to the following conditions:
//
//  The above copyright notice and this permission notice shall be included in all
//  copies or substantial portions of the Software.
//
//  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
//  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
//  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
//  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
//  SOFTWARE.

#import "SettingsAppearance.h"
#import "SettingsAppearanceView.h"
#import "AppHook.h"
#import "BarStatusItem.h"
#import "UserPrefs.h"

@implementation SettingsAppearance

- (void)loadView {
	self.view = [SettingsAppearanceView new];
	for (NSButton *button in self.view.subviews) {
		if ([button isKindOfClass:[NSButton class]]) { // for all checkboxes
			[button setAction:@selector(didSelectCheckbox:)];
			[button setTarget:self];
		}
	}
}

#pragma mark - Checkbox Callback Method

/// Sync new value with UserDefaults and update status bar icon
- (void)didSelectCheckbox:(NSButton*)sender {
	NSString *pref = sender.identifier;
	UserPrefsSetBool(pref, (sender.state == NSControlStateValueOn));
	if (pref == Pref_globalUnreadCount || pref == Pref_globalTintMenuIcon) { // == because static string
		[[(AppHook*)NSApp statusItem] updateBarIcon];
	}
}

@end
